@@ -27,17 +27,20 @@ test_that("upgradeSim preserves comments", {
 
 test_that("Object from version 0.4 can be upgraded", {
     simc.0.4 <- readRDS("assets/simc.0.4.rds")
-    sim <- upgradeSim(simc.0.4)
+    expect_warning(sim <- upgradeSim(simc.0.4),
+                   "The species parameter data frame is missing a `w_max`")
     expect_true(validObject(sim))
 })
 test_that("Object from version 1.0 can be upgraded", {
     simc.1.0 <- readRDS("assets/simc.1.0.rds")
-    sim <- upgradeSim(simc.1.0)
+    expect_warning(sim <- upgradeSim(simc.1.0),
+                   "The species parameter data frame is missing a `w_max`")
     expect_true(validObject(sim))
 })
 test_that("r_max is renamed", {
     params <- NS_params
     params@species_params$r_max <- params@species_params$R_max
+    params@mizer_version <- "1.1"
     expect_message(upgradeParams(params),
                    "The 'r_max' column has been renamed to 'R_max'.")
 })
@@ -45,13 +48,13 @@ test_that("r_max is renamed", {
 test_that("Some functions work with params from earlier versions", {
     params.0.4 <- readRDS("assets/simc.0.4.rds")@params
     expect_warning(getEGrowth(params.0.4),
-                   "You need to upgrade your MizerParams object")
+                   "Your MizerParams object was created with an earlier")
     expect_warning(plotFeedingLevel(params.0.4),
-                   "You need to upgrade your MizerParams object")
+                   "Your MizerParams object was created with an earlier")
     expect_warning(project(params.0.4, t_max = 0.1),
-                   "You need to upgrade your MizerParams object")
+                   "Your MizerParams object was created with an earlier")
     # renaming of resource dynamics functions
     slot(params.0.4, "srr", check = FALSE) <- "srrNone"
-    p4 <- upgradeParams(params.0.4)
+    p4 <- suppressWarnings(upgradeParams(params.0.4))
     expect_identical(p4@rates_funcs$RDD, "noRDD")
-})
\ No newline at end of file
+})
